<?php

/**
 * @file
 * Admin functionality for Cookieinformation.
 */

/**
 * Form callback for the admin settings form.
 *
 * @param array $form
 *   The structure of the form.
 * @param array $form_state
 *   The current state of the form.
 *
 * @return array
 *   The configuration form.
 *
 * @see system_settings_form_submit()
 */
function cookieinformation_settings_form(array $form, array &$form_state) {
  $form['cookieinformation_enable_popup'] = [
    '#type' => 'checkbox',
    '#title' => t('Enable consent popup'),
    '#description' => t('Check to enable the Cookie Information consent popup.'),
    '#default_value' => variable_get('cookieinformation_enable_popup', FALSE),
  ];
  $form['cookieinformation_enable_iab'] = [
    '#type' => 'checkbox',
    '#title' => t('Enable IAB'),
    '#description' => t('Check to enable the IAB (Interactive Advertising Bureau) feature in the Cookie Information consent popup. You will need to use the correct template for the IAB to work. You can switch to the IAB template within the platform.'),
    '#default_value' => variable_get('cookieinformation_enable_iab', FALSE),
    '#states' => [
      'visible' => [
        ':checkbox[name="cookieinformation_enable_popup"]' => ['checked' => TRUE],
      ],
    ],
  ];
  $form['cookieinformation_visibility'] = [
    '#type' => 'fieldset',
    '#title' => t('Cookie Information consent popup visibility'),
    '#states' => [
      'visible' => [
        ':checkbox[name="cookieinformation_enable_popup"]' => ['checked' => TRUE],
      ],
    ],
  ];
  $form['cookieinformation_visibility']['cookieinformation_exclude_paths'] = [
    '#type' => 'textarea',
    '#title' => t('Exclude paths'),
    '#default_value' => variable_get('cookieinformation_exclude_paths', ''),
    '#description' => t("Specify pages by using their paths. Enter one path per line. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", [
      '%blog' => 'blog',
      '%blog-wildcard' => 'blog/*',
      '%front' => '<front>',
    ]),
  ];
  $form['cookieinformation_visibility']['cookieinformation_exclude_admin'] = [
    '#type' => 'checkbox',
    '#title' => t('Exclude admin pages'),
    '#description' => t('Hide the Cookie Information consent popup on administration pages.'),
    '#default_value' => variable_get('cookieinformation_exclude_admin', FALSE)
  ];
  $form['cookieinformation_visibility']['cookieinformation_exclude_uid_1'] = [
    '#type' => 'checkbox',
    '#title' => t('Don’t show the Cookie Information consent popup for UID 1.'),
    '#description' => t('Hide the Cookie Information consent popup for the user with UID 1.'),
    '#default_value' => variable_get('cookieinformation_exclude_uid_1', FALSE)
  ];

  return system_settings_form($form);
}
