<?php

namespace Cookieinformation;

/**
 * The Cookieinformation language service.
 */
class LanguageService {

  /**
   * The currently active language.
   *
   * @var string
   */
  protected $activeLanguage;

  /**
   * A list of rewrite languages.
   *
   * @var array
   */
  protected $rewriteLanguages = [
    'no' => 'nb',
    'nn' => 'nb'
  ];

  /**
   * A list of supported languages.
   *
   * @var array
   */
  protected $supportedLanguages = [
    'ar',
    'bg',
    'ca',
    'cs',
    'da',
    'de',
    'el',
    'en',
    'es',
    'et',
    'fi',
    'fr',
    'ga',
    'he',
    'hi',
    'hr',
    'id',
    'is',
    'it',
    'ja',
    'ko',
    'lt',
    'lv',
    'ms',
    'nb',
    'nl',
    'pl',
    'pt',
    'ro',
    'ru',
    'si',
    'sk',
    'sl',
    'sq',
    'sr',
    'sv',
    'ta',
    'th',
    'tr',
    'uk',
    'vi',
    'zh'
  ];

  /**
   * Constructs a LangaugeService.
   */
  public function __construct() {
    global $language;
    $this->activeLanguage = $language->language;
  }

  /**
   * Find the current language ID, rewrite and validate if it is supported.
   * Fallback to 'en' if the language current language ID is not supported.
   *
   * @return string
   *  The found language ID.
   */
  public function getId() {
    $language = substr($this->activeLanguage, 0, 2);

    // Rewrite language code
    if (isset($this->rewriteLanguages[$language])) {
      $language = $this->rewriteLanguages[$language];
    }

    return in_array($language, $this->supportedLanguages) ? $language : 'en';
  }

}

