<?php
namespace Cookieinformation;

/**
 * The Cookieinformation visibility service.
 */
class VisibilityService {

  /**
   * The current user.
   *
   * @var object
   */
  protected $currentUser;

  /**
   * Constructs a VisibilityService.
   */
  public function __construct() {
    global $user;
    $this->currentUser = $user;
  }

  /**
   * Check if cookie information consent popup is enabled.
   *
   * @return bool
   *   TRUE if yes, FALSE if no.
   */
  public function checkEnabled() {
    if (variable_get('cookieinformation_enable_popup', FALSE)) {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * Check if the user has permission to see the page without the consent popup.
   *
   * @return bool
   *   TRUE if yes, FALSE if no.
   */
  public function checkPermissions() {
    if ((int) $this->currentUser->uid !== 1 && user_access('disable cookie information consent')) {
      return FALSE;
    }

    return TRUE;
  }

  /**
   * Check if the current user is uid = 1 and consent popup is disabled for
   * this user.
   *
   * @return bool
   *   FALSE if yes, TRUE if no.
   */
  public function checkUser1() {
    if ((int) $this->currentUser->uid === 1 && variable_get('cookieinformation_exclude_uid_1', FALSE)) {
      return FALSE;
    }

    return TRUE;
  }

  /**
   * Check if consent popup is disabled on admin routes.
   *
   * @return bool
   *   TRUE if yes, FALSE if no.
   */
  public function checkAdminRoutes() {
    if (variable_get('cookieinformation_exclude_admin', FALSE)) {
      if (path_is_admin(current_path())) {
        return FALSE;
      }
    }

    return TRUE;
  }

  /**
   * Check exclude paths.
   *
   * @return bool
   *   TRUE if yes, FALSE if no.
   */
  public function checkExcludePaths() {
    $pages = variable_get('cookieinformation_exclude_paths', '');

    if (!empty($pages)) {

      // Convert path to lowercase. This allows comparison of the same path
      // with different case. Ex: /Page, /page, /PAGE.
      $pages = drupal_strtolower($pages);

      // Convert the Drupal path to lowercase.
      $path = drupal_strtolower(drupal_get_path_alias($_GET['q']));

      // Compare the lowercase internal and lowercase path alias (if any).
      $page_match = drupal_match_path($path, $pages);
      if ($path != $_GET['q']) {
        $page_match = $page_match || drupal_match_path($_GET['q'], $pages);
      }

      if ($page_match) {
        return FALSE;
      }
    }

    return TRUE;
  }

  /**
   * Check all "in once".
   *
   * @return bool
   *   TRUE if yes, FALSE if no.
   */
  public function checkAll() {
    if ($this->checkEnabled() && $this->checkPermissions() && $this->checkUser1() && $this->checkAdminRoutes() && $this->checkExcludePaths()) {
      return TRUE;
    }

    return FALSE;
  }

}
